4. Data as objects — CubicWeb 3.10.1

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.10.1 »
- Repository development »

# 4. Data as objects

In this chapter, we will introduce the objects that are used to handle the logic associated to the data stored in the database.

- 4.1. Access to persistent data
- 4.2. The `AnyEntity` class
- 4.3. Inheritance
- 4.4. Application logic
- 4.5. Loaded attributes and default sorting management
- 4.6. Interfaces and Adapters
- 4.7. How to use entities objects and adapters
- 4.8. Anatomy of an entity class

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.10.1 »
- Repository development »